@@ -12,6 +12,8 @@ impl Loader for NoOpLoader {
     fn load(&self, _: &str) -> Result<String, LoadError> {
         Ok(String::default())
     }
+    
+    fn root_path(&self) -> Result<std::string::String, nasl_syntax::LoadError> { todo!() }
 }
 
 #[cfg(test)]
@@ -38,7 +40,7 @@ mod tests {
 
     #[test]
     fn description() {
-        let code = r###"
+        let code = r#"
 rc = 23;
 if(description)
 {
@@ -61,7 +63,7 @@ if(description)
   script_add_preference(name:"Without ID", type:"password", value:"");
   exit(rc);
 }
-        "###;
+        "#;
         let storage = DefaultDispatcher::new(true);
         let loader = NoOpLoader::default();
         let initial = [(
